Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2014-01-13 07:53:41 +0400
committerCampbell Barton <ideasman42@gmail.com>2014-01-13 08:31:57 +0400
commit61ff3dfdda3aa80323fb2c0324e1813a7b136a88 (patch)
tree82089c8d8c513b68999e3d99f4135ec24e8fef8b /source/blender/blenlib/intern/polyfill2d.c
parent717bf85545989eb91d429108202294da24cbb565 (diff)
Code Cleanup: spelling
Diffstat (limited to 'source/blender/blenlib/intern/polyfill2d.c')
-rw-r--r--source/blender/blenlib/intern/polyfill2d.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/blender/blenlib/intern/polyfill2d.c b/source/blender/blenlib/intern/polyfill2d.c
index f5a226cebb6..9168d2f3228 100644
--- a/source/blender/blenlib/intern/polyfill2d.c
+++ b/source/blender/blenlib/intern/polyfill2d.c
@@ -433,7 +433,7 @@ void BLI_polyfill_calc_arena(
struct MemArena *arena)
{
- unsigned int *indicies = BLI_memarena_alloc(arena, sizeof(*indicies) * coords_tot);
+ unsigned int *indices = BLI_memarena_alloc(arena, sizeof(*indices) * coords_tot);
eSign *coords_sign = BLI_memarena_alloc(arena, sizeof(*coords_sign) * coords_tot);
BLI_polyfill_calc_ex(
@@ -441,9 +441,9 @@ void BLI_polyfill_calc_arena(
r_tris,
/* cache */
- indicies, coords_sign);
+ indices, coords_sign);
- /* indicies & coords_sign are no longer needed,
+ /* indices & coords_sign are no longer needed,
* caller can clear arena */
}
@@ -452,7 +452,7 @@ void BLI_polyfill_calc(
const unsigned int coords_tot,
unsigned int (*r_tris)[3])
{
- unsigned int *indicies = BLI_array_alloca(indicies, coords_tot);
+ unsigned int *indices = BLI_array_alloca(indices, coords_tot);
eSign *coords_sign = BLI_array_alloca(coords_sign, coords_tot);
BLI_polyfill_calc_ex(
@@ -460,5 +460,5 @@ void BLI_polyfill_calc(
r_tris,
/* cache */
- indicies, coords_sign);
+ indices, coords_sign);
}